/*
 *  linux/arch/arm/mach-psionw/leds.c
 *
 *  Psionw LED control routines
 *
 *  Copyright (C) 2000 Deep Blue Solutions Ltd
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <linux/kernel.h>
#include <linux/init.h>

#include <asm/hardware.h>
#include <asm/io.h>
#include <asm/leds.h>
#include <asm/system.h>
#include <asm/mach-types.h>

#include <asm/hardware/psionw.h>

static void psionw_leds_event(led_event_t ledevt)
{
	unsigned long flags;
	u32 port;

	local_irq_save(flags);
	switch(ledevt) {
	case led_idle_start:
		/* 
		 * Turn off red front led when entering idle.
		 * The led then shows the current CPU load.
		 */
		port = psionw_readb(PDDR);
		psionw_writeb(port & ~PDDR_SLED, PDDR);
		break;

	case led_idle_end:
		/* Turn on red front led when not idle*/
		port = psionw_readb(PDDR);
		psionw_writeb(port | PDDR_SLED, PDDR);
		break;

	case led_timer:
		/* FIXME5MX Blink the green top led, does not work */
		port = psionw_readb(PCDR);
		//psionw_writeb(port ^ PCDR_PLED, PCDR);
		break;

	default:
		break;
	}

	local_irq_restore(flags);
}

static int __init leds_init(void)
{
	leds_event = psionw_leds_event;
	return 0;
}

__initcall(leds_init);
